@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2011-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2011-2019 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -238,7 +238,8 @@ class Command(BaseCommand):
                  "for batch imports)")
         parser.add_argument(
             '--since',
-            help="only import emails later than this date")
+            help="only import emails later than this date.  Defaults to the "
+                 "date of the newest message in the existing archive if any.")
         parser.add_argument(
             '--ignore-mtime',
             action='store_true', default=False,
